=======
History
=======

0.5.0 (2018-12-06)
------------------

* Implement 'contains' operator in all parsers
* Refactor 'like' and 'ilike' operators in all parsers


0.4.0 (2018-04-24)
------------------

* Implement 'ilike' operator in all parsers

0.3.0 (2018-03-19)
------------------

* Implement 'sql' command returning a (query, params) tuple
* Remove single quote handling in string parser

0.2.1 (2018-03-19)
------------------

* Increase test coverage for comparison operators
* Fix parse error when given a list of lists domain
* Quote (') string values in string parser (for SQL clauses)

0.2.0 (2018-03-03)
------------------

* API creation.
* Parse domain list to string.
* Parse domain list to expression.

0.1.0 (2018-02-18)
------------------

* First release on PyPI.
